/* -*- c++ -*- */

//=============================================================================
/**
 *  @file    be_visitor_root.h
 *
 *  $Id: be_visitor_root.h 88919 2010-02-09 22:55:55Z parsons $
 *
 *  Concrete visitor for the Root class
 *
 *
 *  @author Aniruddha Gokhale and Carlos O'Ryan
 */
//=============================================================================


#ifndef TAO_BE_VISITOR_ROOT_H
#define TAO_BE_VISITOR_ROOT_H

#include "be_visitor_scope.h"
#include "be_visitor_root/root.h"
#include "be_visitor_root/root_ch.h"
#include "be_visitor_root/root_ci.h"
#include "be_visitor_root/root_cs.h"
#include "be_visitor_root/root_sh.h"
#include "be_visitor_root/root_si.h"
#include "be_visitor_root/root_ss.h"
#include "be_visitor_root/root_sth.h"
#include "be_visitor_root/root_is.h"
#include "be_visitor_root/root_ih.h"
#include "be_visitor_root/root_svh.h"
#include "be_visitor_root/root_svs.h"
#include "be_visitor_root/root_ex_idl.h"
#include "be_visitor_root/root_exh.h"
#include "be_visitor_root/root_exs.h"
#include "be_visitor_root/root_cnh.h"
#include "be_visitor_root/root_cns.h"
#include "be_visitor_root/any_op.h"
#include "be_visitor_root/cdr_op.h"
#include "be_visitor_root/serializer_op.h"

#endif // TAO_BE_VISITOR_ROOT_H
